"use client";

import { IoIosArrowBack } from "react-icons/io";
import { RadioGroup, Radio } from "@headlessui/react";
import { useState, useEffect } from "react";
import { isValidPhoneNumber } from "@/utils/utils";
import { useToast } from "@/contexts/ToastContext";
import * as Form from "@radix-ui/react-form";
import useFetch from "@/hooks/useFetch";
import { useTranslations } from "next-intl";
import Link from "next/link";

interface RegisterFormProps {
  back: () => void;
}

const plans: Plan[] = ["phone", "email"];

type Plan = "phone" | "email";

export default function RegisterForm({ back }: RegisterFormProps) {
  const t = useTranslations("registerForm");
  const tTerms = useTranslations("terms"); // 用于获取用户协议的标题
  const tGlobal = useTranslations(); // 用于获取全局翻译，如 "agreeTo" 和 "agreeToTerms"
  const [selected, setSelected] = useState<Plan>(plans[0]);
  const [email, setEmail] = useState("");
  const [phone, setPhone] = useState("");
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");
  const [confirmPassword, setConfirmPassword] = useState("");
  const [captcha, setCaptcha] = useState("");
  const [captchaTimer, setCaptchaTimer] = useState(0);
  const [agreed, setAgreed] = useState(true); // 默认勾选

  const { addToast } = useToast();

  // 获取验证码
  const {
    fetchData: fetchVerificationCode,
    data: verificationData,
    loading: verificationLoading,
    error: verificationError,
  } = useFetch({
    url: "/api/send-verification-sms/",
    method: "POST",
  });

  // 注册
  const {
    fetchData: register,
    data: registerData,
    loading: registerLoading,
    error: registerError,
  } = useFetch({
    url: "/api/register/",
    method: "POST",
  });

  useEffect(() => {
    let timer: NodeJS.Timeout;
    if (captchaTimer > 0) {
      timer = setInterval(() => {
        setCaptchaTimer((prev) => prev - 1);
      }, 1000);
    }
    return () => clearInterval(timer);
  }, [captchaTimer]);

  const handleGetCaptcha = async () => {
    if (selected === "phone" && !isValidPhoneNumber(phone)) {
      addToast(t("invalidPhoneNumber"), "error");
      return;
    }

    if (selected === "email" && !email) {
      addToast(t("enterEmail"), "error");
      return;
    }

    const data =
      selected === "phone" ? { phone_number: phone } : { email: email };

    await fetchVerificationCode(data);
    setCaptchaTimer(60);
  };

  useEffect(() => {
    if (verificationData?.code === 200) {
      addToast(t("captchaSent"), "success");
      setCaptchaTimer(60);
    }
  }, [verificationData, verificationError]);

  const handleSubmit = async (event: React.FormEvent<HTMLFormElement>) => {
    event.preventDefault(); // 阻止表单默认提交行为

    if (!agreed) {
      addToast(tGlobal("agreeToTerms"), "error");
      return;
    }

    // 校验非空字段
    if (!username || !password || !confirmPassword || !captcha) {
      addToast(t("completeInformation"), "error");
      return;
    }

    if (password !== confirmPassword) {
      addToast(t("passwordMismatch"), "error");
      return;
    }

    // 检查 email 或 phone 是否有效
    if (selected === "email" && !email) {
      addToast(t("enterEmail"), "error");
      return;
    }

    if (selected === "phone" && !phone) {
      addToast(t("enterPhoneNumber"), "error");
      return;
    }

    // 构建注册请求参数
    const registerData = {
      code: captcha,
      confirm_password: confirmPassword,
      password,
      username,
      registerMethod: selected,
      ...(selected === "email" && { email }), // 仅当 selected 为 "email" 时添加 email 字段
      ...(selected === "phone" && { phone }), // 仅当 selected 为 "phone" 时添加 phone 字段
    };

    // 调用 register 函数发送注册请求
    await register(registerData);
  };

  return (
    <div className="flex flex-col items-center gap-[25px] py-8 bg-black/80 rounded-lg shadow-lg px-8 w-[400px]">
      <div className="w-full flex items-center justify-between mb-4 ">
        <button
          className="text-gray-300 hover:text-white"
          onClick={back}
        >
          <IoIosArrowBack size={24} />
        </button>
        <div className="text-xl font-bold text-center text-gray-300">
          {t("register")}
        </div>
        <div className="w-6"></div> {/* 占位符，使标题居中 */}
      </div>
      <Form.Root className="w-full" onSubmit={handleSubmit}>
        <div className="w-full flex flex-col gap-4">
          <Form.Field name="radio">
            <RadioGroup
              value={selected}
              onChange={setSelected}
              aria-label={t("registrationMethod")}
              className="flex items-center justify-center gap-6"
            >
              {plans.map((plan) => (
                <div key={plan} className="flex items-center gap-2">
                  <Radio
                    id={plan}
                    value={plan}
                    className="cursor-pointer group flex h-5 w-5 items-center justify-center rounded-full border bg-gray-700 data-[checked]:bg-green-500"
                  >
                    <span className="invisible h-2 w-2 rounded-full bg-white group-data-[checked]:visible" />
                  </Radio>
                  <Form.Label htmlFor={plan} className="text-gray-300">
                    {t(plan)}
                  </Form.Label>
                </div>
              ))}
            </RadioGroup>
          </Form.Field>

          {selected === "email" && (
            <Form.Field name="email">
              <input
                type="email"
                id="email"
                value={email}
                onChange={(e) => setEmail(e.target.value)}
                className="h-10 input border-gray-600 bg-gray-800 focus:outline-none w-full rounded-lg text-sm text-gray-300 placeholder-gray-500"
                placeholder={t("email")}
              />
            </Form.Field>
          )}
          {selected === "phone" && (
            <Form.Field name="phone">
              <input
                type="tel"
                id="phone"
                value={phone}
                onChange={(e) => setPhone(e.target.value)}
                className="h-10 input border-gray-600 bg-gray-800 focus:outline-none w-full rounded-lg text-sm text-gray-300 placeholder-gray-500"
                placeholder={t("phoneNumber")}
              />
            </Form.Field>
          )}

          {/* 用户名 */}
          <Form.Field name="username">
            <input
              type="text"
              id="username"
              value={username}
              onChange={(e) => setUsername(e.target.value)}
              className="h-10 input border-gray-600 bg-gray-800 focus:outline-none w-full rounded-lg text-sm text-gray-300 placeholder-gray-500"
              placeholder={t("username")}
            />
          </Form.Field>

          {/* 密码 */}
          <Form.Field name="password">
            <input
              type="password"
              id="password"
              value={password}
              onChange={(e) => setPassword(e.target.value)}
              className="h-10 input border-gray-600 bg-gray-800 focus:outline-none w-full rounded-lg text-sm text-gray-300 placeholder-gray-500"
              placeholder={t("password")}
            />
          </Form.Field>

          {/* 确认密码 */}
          <Form.Field name="confirmPassword">
            <input
              type="password"
              id="confirmPassword"
              value={confirmPassword}
              onChange={(e) => setConfirmPassword(e.target.value)}
              className="h-10 input border-gray-600 bg-gray-800 focus:outline-none w-full rounded-lg text-sm text-gray-300 placeholder-gray-500"
              placeholder={t("confirmPassword")}
            />
          </Form.Field>

          {/* 验证码 */}
          <Form.Field name="captcha">
            <div className="flex items-center">
              <input
                type="text"
                id="captcha"
                value={captcha}
                onChange={(e) => setCaptcha(e.target.value)}
                className="h-10 input border-gray-600 bg-gray-800 focus:outline-none w-full rounded-lg text-sm text-gray-300 placeholder-gray-500"
                placeholder={t("captcha")}
              />
              <button
                type="button"
                onClick={handleGetCaptcha}
                className="btn h-10 btn-sm w-32 ml-2 bg-transparent hover:bg-green-500 hover:text-white text-gray-500 rounded-lg"
                disabled={captchaTimer > 0 || verificationLoading}
              >
                {verificationLoading ? (
                  <span className="loading loading-spinner loading-md"></span>
                ) : captchaTimer > 0 ? (
                  `${captchaTimer}s`
                ) : (
                  t("getCode")
                )}
              </button>
            </div>
          </Form.Field>

          {/* 用户协议复选框 */}
          <Form.Field name="agreement">
            <div className="flex items-center justify-between">
              <label className="flex items-center text-gray-300 text-sm">
                <input
                  type="checkbox"
                  checked={agreed}
                  onChange={(e) => setAgreed(e.target.checked)}
                  className="h-4 w-4 text-green-500 bg-gray-700 border-gray-600 rounded focus:ring-green-500"
                />
                <span className="ml-2">
                  {tGlobal("agreeTo")}{" "}
                  <Link href="/terms" className="text-green-500 underline">
                    {tTerms("title")}
                  </Link>
                </span>
              </label>
            </div>
          </Form.Field>

          <Form.Submit
            disabled={registerLoading}
            className="btn bg-transparent hover:bg-green-500 text-gray-300 w-full rounded-lg hover:text-white border border-gray-600"
          >
            {t("submit")}
            {registerLoading ? (
              <span className="loading loading-spinner loading-md ml-2"></span>
            ) : null}
          </Form.Submit>
        </div>
      </Form.Root>
    </div>
  );
}
